'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _cfStyleContainer = require('cf-style-container');

var _reactTooltip = require('react-tooltip');

var _reactTooltip2 = _interopRequireDefault(_reactTooltip);

var _lodash = require('lodash.uniqueid');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getBackgroundColor = (colors, type) => {
  if (type === 'dark') {
    return `${colors.gray[1]} !important`;
  }

  if (type === 'success') {
    return `${colors.green[6]} !important`;
  }

  return 'inherit';
};
const tooltipStyles = ({ theme, type, place }) => ({
  '&:after': {
    borderTopColor: place === 'top' ? getBackgroundColor(theme.colors, type) : 'inherit',
    borderRightColor: place === 'right' ? getBackgroundColor(theme.colors, type) : 'inherit',
    borderLeftColor: place === 'left' ? getBackgroundColor(theme.colors, type) : 'inherit',
    borderBottomColor: place === 'bottom' ? getBackgroundColor(theme.colors, type) : 'inherit'
  },
  backgroundColor: getBackgroundColor(theme.colors, type),
  opacity: '1!important',
  fontSize: '0.8rem!important',
  borderRadius: '2px!important',
  maxWidth: '21rem!important',
  padding: '0.5rem 1rem!important',
  fontWeight: 'normal!important',
  lineHeight: '1.5!important',
  pointerEvents: 'auto !important',
  verticalAlign: 'baseline!important',
  whiteSpace: 'normal',
  '&:hover': {
    visibility: 'visible!important',
    opacity: '1!important'
  }
});

class Tooltip extends _react2.default.Component {
  constructor(props) {
    super(props);
    this.id = (0, _lodash2.default)('cf_component_tooltip_');
  }

  componentDidUpdate() {
    _reactTooltip2.default.rebuild();

    // full rebuild is required when tooltip is already displayed
    // but we changed type of position of the tooltip
    if (this.props.forceRebuild) {
      _reactTooltip2.default.hide(this.tooltipElement);
      setTimeout(() => _reactTooltip2.default.show(this.tooltipElement), 0);
    }
  }

  render() {
    const {
      place,
      message,
      children,
      className,
      delayHide,
      afterHide,
      afterShow,
      getContent,
      type
    } = this.props;
    const id = this.props.id ? this.props.id : this.id;
    return _react2.default.createElement(
      'span',
      null,
      _react2.default.createElement(_reactTooltip2.default, {
        id: id,
        place: place,
        type: type,
        'aria-haspopup': 'true',
        role: 'tooltip',
        effect: 'solid',
        className: className,
        isCapture: true,
        delayHide: delayHide ? delayHide : null,
        afterShow: afterShow,
        afterHide: afterHide,
        getContent: [() => message || getContent()]
      }),
      _react2.default.createElement(
        'div',
        {
          ref: c => {
            this.tooltipElement = c;
          },
          'data-tip': true,
          'data-for': id
        },
        children
      )
    );
  }
}

Tooltip.propTypes = {
  id: _propTypes2.default.string,
  message: _propTypes2.default.node.isRequired,
  place: _propTypes2.default.oneOf(['top', 'right', 'bottom', 'left']),
  type: _propTypes2.default.oneOf(['dark', 'success', 'warning', 'error', 'info', 'light']),
  className: _propTypes2.default.string,
  children: _propTypes2.default.node,
  delayHide: _propTypes2.default.number,
  afterHide: _propTypes2.default.func,
  afterShow: _propTypes2.default.func,
  getContent: _propTypes2.default.func,
  forceRebuild: _propTypes2.default.bool
};

Tooltip.defaultProps = {
  position: 'top',
  type: 'dark',
  forceRebuild: false
};

Tooltip.displayName = 'Tooltip';

exports.default = (0, _cfStyleContainer.createComponent)(tooltipStyles, Tooltip, ['message', 'id', 'place', 'className', 'children', 'afterHide', 'afterShow', 'getContent', 'type', 'forceRebuild']);